podcust.demo package
====================

Submodules
----------

podcust.demo.custodian module
-----------------------------

.. automodule:: podcust.demo.custodian
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: podcust.demo
   :members:
   :undoc-members:
   :show-inheritance:
